# Copyrights 2001-2004,2007 by Mark Overmeer <perl@overmeer.net>.
#  For other contributors see Changes.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 1.00.

use strict;
use warnings;

package A::B;
use vars '$VERSION';
$VERSION = '0.17';
use base 'A';

sub a_b() {'a_b'}

1;
